pub struct UnlinkOnDrop { /* private fields */ }Expand description
Drop-guard that unlinks a path on drop unless disarm is called.
Used to ensure that any failure between temp-file open and final rename leaves the filesystem clean.
Implementations