SaveReport

Struct SaveReport 

pub struct SaveReport {
    pub kind: SnapshotKind,
    pub pages_written: u64,
}
Save report — emitted after a successful save for tracing / metrics.

Fields

kind: SnapshotKind

Snapshot kind that produced this save.

pages_written: u64

Number of pages written for a Diff snapshot (= 0 for Full, where every page is written via the dense write path).