pub struct SaveReport {
pub kind: SnapshotKind,
pub pages_written: u64,
}Expand description
Save report — emitted after a successful save for tracing / metrics.
Fields
kind: SnapshotKindSnapshot kind that produced this save.
pages_written: u64Number of pages written for a Diff snapshot (= 0 for Full, where every page is written via the dense write path).